@@ -728,6 +728,17 @@ class SimpleCodebuildProject(
         '''
         return typing.cast("SimpleCodebuildProject", jsii.invoke(self, "triggerBuildOnSchedule", [schedule]))
 
+    @jsii.member(jsii_name="triggerOnPushToBranches")
+    def trigger_on_push_to_branches(
+        self,
+        branches: typing.Sequence[builtins.str],
+    ) -> "SimpleCodebuildProject":
+        '''Triggers build on push to specified branches.
+
+        :param branches: -
+        '''
+        return typing.cast("SimpleCodebuildProject", jsii.invoke(self, "triggerOnPushToBranches", [branches]))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="project")
     def project(self) -> typing.Optional[aws_cdk.aws_codebuild.Project]:
